aboutsummaryrefslogtreecommitdiffstats
path: root/test/utils.rb
diff options
context:
space:
mode:
authorKazuki Yamaguchi <k@rhe.jp>2016-08-18 22:19:44 +0900
committerKazuki Yamaguchi <k@rhe.jp>2016-08-18 22:24:12 +0900
commit207ead9c689241d1746a8515946fc7fc0685bd29 (patch)
tree15785a641cbd60ed8d0da3a32834d482da24d695 /test/utils.rb
parent376df2612386213982065c198cb048859004a335 (diff)
downloadruby-openssl-207ead9c689241d1746a8515946fc7fc0685bd29.tar.gz
test: rename MDEBUG environment variable to OSSL_MDEBUG
Diffstat (limited to 'test/utils.rb')
-rw-r--r--test/utils.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/utils.rb b/test/utils.rb
index fc303d1d..6b1487d3 100644
--- a/test/utils.rb
+++ b/test/utils.rb
@@ -9,9 +9,9 @@ begin
rescue LoadError
end
# Compile OpenSSL with crypto-mdebug and run this test suite with MDEBUG
# environment variable to enable memory leak check.
-if ENV["MDEBUG"]
+if ENV["OSSL_MDEBUG"] == "1"
begin
require "mdebug"
rescue LoadError
@@ -9,9 +9,9 @@ begin
rescue LoadError
end
-# Compile OpenSSL with crypto-mdebug and run this test suite with MDEBUG
+# Compile OpenSSL with crypto-mdebug and run this test suite with OSSL_MDEBUG=1
# environment variable to enable memory leak check.